@@ -6,11 +6,11 @@
      *	RecoilKineMinE /250.e-6/,   ! < 250 keV ==> dE/dx
      *  AnihiE /30.e-3/,            ! Eposi < 30 MeV, anihilation considered
      *  X0 /364.0/,                 ! radiation length of air in kg/m2
-     *  Ecrit /76.e-3/,             ! critical energy of air in GeV
+     *  Ecrit /81.e-3/,             ! critical energy of air in GeV
      *  MaxComptonE /75.e-3/,       ! compton is considered below 75 MeV
      *  MaxPhotoE /0./,             ! above this, PhotoElectric effect neg.
      *  MinPhotoProdE /150.e-3/,     ! below 150 MeV, no gp --> hadrons
-     *	Es /20.e-3/,                 ! scattering const. Note, not 21 MeV.
+     *	Es /19.3d-3/,                 ! scattering const. Note, not 21 MeV.
      *  Knockon /.true./,            ! knockon is considered.
      *  PhotoProd /.false./,        ! gp--> hadrons not considered.
      *  Moliere /1/                 ! Moliere scattering for non-electron 
