@@ -11,7 +11,7 @@ c
 #include  "Zincidentp.h" 
 #include  "Zprimary.h"
 #include  "Zprimaryv.h"
-
+#include  "Zcondc.h"
 
       character*70 msg
       character*16 temp
@@ -55,6 +55,13 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
          write(msg, *) 'IntModel=', IntModel,' not supported'
          call cerrorMsg(msg, 0)
       endif
+#if ATMOSPHERE == 1
+c          read segmented atmosphere data
+      call creadAtmosD
+c          manipulate data
+      call catmosCnst1
+      call catmosCnst2
+#endif
 c        init for LPM effect energy sampling.
       s1 = (7.36d0**(1./3.d0)/183.d0)**2
       call csetLPMCnst(s1, log(s1), 1.d-4, X0)
@@ -92,6 +99,7 @@ c         user hook
 #include  "Zobsv.h"
 #include  "Zincidentp.h"
 #include  "Zheavyv.h"
+
 c
       integer i
 
@@ -121,6 +129,7 @@ c        make it offset
          Offset.r(i) = Offset.r(i) -
      *    ObsSites(NoOfSites).pos.xyz.r(i)
       enddo
+
       end
 c     ************
       subroutine  cwhatJob
