@@ -29,6 +29,8 @@ c           (except for hadronic interactions)
 
       Nproduced = 0
 
+      aTrack = MovedTrack   !  save incident
+
       if(MovedTrack.p.code .eq. kelec) then
          call cinteElec
          if(neverE .ne. 1) then
@@ -57,15 +59,12 @@ c             interface with user hook  ***********************
 c             *******************************
       endif
 
-
       if( never .eq. 1 .or. never .eq. 0) then
          if(OneDim .eq. 0) then
 c            3 dimensional
-            aTrack = MovedTrack ! copy inf. other than /ptcl/
 c                 stack the leading ptcl  first (to save stack area)
             call cmovePtcl3(aTrack, Pwork, Nproduced)
          else
-            aTrack = MovedTrack
             aTrack.vec = IncidentCopy.vec
             call cmovePtcl1(aTrack, Pwork, Nproduced)
          endif
@@ -79,11 +78,9 @@ c               get fragment and non interacting nuc.
             call cqHvyIntNIN(nonIntNucA, noOfNonIntN)
 
             if(OneDim .eq. 0) then
-                aTrack = MovedTrack ! copy inf. other than /ptcl/
                 call cmovePtcl3(aTrack, fragA, noOfFrag)
                 call cmovePtcl3(aTrack, nonIntNucA, noOfNonIntN)
              else
-                aTrack = MovedTrack
                 aTrack.vec = IncidentCopy.vec
                 call cmovePtcl1(aTrack, fragA, noOfFrag)
                 call cmovePtcl1(aTrack, nonIntNucA, noOfNonIntN)
@@ -103,18 +100,26 @@ c     ************************************
 c          move partcles in a given array to stack
 c          3 dimensional case.
 
-      subroutine  cmovePtcl3(aTrack, pw, n)
+      subroutine  cmovePtcl3(iTrack, pw, n)
       implicit none
-
+#include  "Ztrackp.h"
 #include  "Ztrack.h"
+#include  "Ztrackv.h"
 c
       integer n
-      record /track/ aTrack
+      record /track/ iTrack  ! input. incident ptcl.
       record /ptcl/ pw(n)
+      logical needThin
 
-      integer i
+      record /track/ aTrack  
+      integer i, icon
+      
+      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+
+      aTrack = iTrack
 
       do i =  n, 1, -1          ! move leading ptcl first
+
 #ifdef SUBSTREC
          aTrack.p = pw(i)
 #else
@@ -126,28 +131,43 @@ c
 #endif
 c               reset direction cos and related stuffs
          call cresetDirec(aTrack)
-         call cpush(aTrack)
+
+         aTrack.wgt=iTrack.wgt
+         if(needThin) then
+            call csetThinwgt(iTrack, aTrack,  icon)
+         else
+            icon = 0
+         endif
+         if(icon .eq.0) call cpush(aTrack)
       enddo
       end
 c     ************************************
 c          move partcles in a given array to stack
 c          1 dimensional case.
 
-      subroutine  cmovePtcl1(aTrack, pw, n)
+      subroutine  cmovePtcl1(iTrack, pw, n)
       implicit none
 
 
 #include  "Ztrack.h"
 #include  "Ztrackp.h"
+#include  "Ztrackv.h"
 #include  "Zincidentv.h"
 
 
       integer n
-      record /track/ aTrack
+      record /track/ iTrack   ! input. incident track
       record /ptcl/ pw(n)
       real*8 temp, p
-  
-      integer i
+      logical needThin
+      integer i, icon
+      
+      record /track/ aTrack 
+
+      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+
+      aTrack = iTrack
+
       do i =  n, 1, -1          ! move leading ptcl last
 #ifdef SUBSTREC
          aTrack.p = pw(i)
@@ -174,7 +194,13 @@ c            call cresetMom(aTrack)  which is
             aTrack.p.fm.p(3) = p * aTrack.vec.w.r(3)
 
             call cgetZenith(aTrack, aTrack.vec.coszenith)
-            call cpush(aTrack)
+            aTrack.wgt = iTrack.wgt
+            if(needThin) then
+               call csetThinwgt(iTrack, aTrack, icon)
+            else
+               icon = 0
+            endif
+            if(icon .eq. 0) call cpush(aTrack)
          endif
       enddo
       end
@@ -213,5 +239,28 @@ c
 #endif
       endif
       end
+c     ***************************
+      subroutine csetThinwgt(iTrack, aTrack, icon)
+      implicit none
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+      record /track/ iTrack   ! input   particle
+      record /track/ aTrack  ! input/output.    particle
+      integer icon           ! output.  0 if this is not tobe discarded
+                             !          1 if this is to be discarded
+      real*8 iwgt, u
+
+
+
+      iwgt = aTrack.p.fm.p(4)/iTrack.p.fm.p(4) ! inverse weight
+
+      call rndc(u)
+      if(u .gt. iwgt) then
+         icon =1                !  discard this ptcl
+      else
+         aTrack.wgt = aTrack.wgt /iwgt
+         icon = 0
+      endif
+      end
+
 
-      
