@@ -1,6 +1,5 @@
 c              test primary sampling routines
-#include  "BlockData/cblkHeavy.h"
-#include  "BlockData/cblkIncident.h"
+#include  "BlockData/cblkGene.h"
 
       implicit none
 #include  "Zmanagerp.h"
@@ -18,21 +17,6 @@ c              test primary sampling routines
 
       call creadParam(5)
       call cbeginRun
-c      call cerrorMsg('Enter the path to the primary data file', 1)
-c      read(*, '(a)') fn
-c      CutOffFile = ' '
-c      call cerrorMsg('Enter the path to the cutoff file, if any', 1)
-c     read(*, '(a)') CutOffFile
-
-c      call ciniSPrim(fn)
-c      if(CutOffFile .ne. ' ') then
-c         call crigCut0(CutOffFile) ! read cutoff talbe and init.
-c         call cerrorMsg('Enter coszenith region', 1)
-c         read(*, *) CosZenith
-c      endif
-      
-c      call cerrorMsg('Enter # of samplings', 1)
-c      read(*,*) howmany
       call cprintPrim(ErrorOut)
       write(ErrorOut, 
      *   '("#seq. No.|   Orig Erg | Code # | Total E(GeV)")')
@@ -51,10 +35,8 @@ c      read(*,*) howmany
          call cqPrimE(kin)
          call cqPrimLabel(label)
          p = incident.p
-c         write(*,'(i9,g12.4,i8, g12.4)') label, sngl(kin),
-c     *        p.code,  sngl(p.fm.p(4)), sngl(log10(kin))
          write(*, *) label, sngl(kin),
-     *        p.code,  sngl(p.fm.p(4)), sngl(log10(kin))
+     *      p.code,  sngl(p.fm.p(4)), sngl(log10(kin)), sngl(1/kin)
       enddo
       end
       subroutine chookTrace
@@ -66,4 +48,4 @@ c     *        p.code,  sngl(p.fm.p(4)), sngl(log10(kin))
       subroutine chookCerenE
       end
       subroutine chookBgRun
-      end 
+      end
